@@ -1302,9 +1302,9 @@ class PatientFHIR(BaseFHIR):
 
     headers = {}
     fhir_resource = None
-    def __init__(self, base_url=None, base_uri=None, patient_dict=None, token=None, patient_resource_dict=None):
+    def __init__(self, base_url=None, base_uri=None, patient_dict=None, token=None, patient_resource_dict=None, validate_certs=True):
         super().__init__(base_url=base_url, base_uri=base_uri)
-
+        self.validate_certs = validate_certs
         if patient_resource_dict is None and patient_dict is not None:
             self.from_dict(patient_dict)
             self.fhir_resource = self.patient_dict_to_fhir_patient(patient_dict=patient_dict, patient=Patient())
@@ -1370,24 +1370,24 @@ class PatientFHIR(BaseFHIR):
     def Create(self):
         res = self.getFhirResource()
         response = requests.post(url=self.patient_endpoint.format(
-            self.get_fhir_url()), data=json.dumps(res), headers=self.headers)
+            self.get_fhir_url()), data=json.dumps(res), headers=self.headers, verify=self.validate_certs)
         self.from_json(resource=response.content.decode())
         if self.niu is not None:
             res = self.getFhirResourceParameter()
             requests.post(url=self.patient_definir_niu_endpoint.format(
-                self.get_fhir_url(), self.id), data=json.dumps(res), headers=self.headers)
+                self.get_fhir_url(), self.id), data=json.dumps(res), headers=self.headers, verify=self.validate_certs)
         return response
 
     def GetById(self, patient_id=None):
         response = requests.get(url=self.patient_id_endpoint.format(
-            self.get_fhir_url(), patient_id), headers=self.headers)
+            self.get_fhir_url(), patient_id), headers=self.headers, verify=self.validate_certs)
         self.from_json(resource=response.content.decode())
         return response
 
     def Match(self):
         res = self.getFhirResourceParameter()
         response = requests.post(url=self.patient_match_endpoint.format(
-            self.get_fhir_url()), data=json.dumps(res), headers=self.headers)
+            self.get_fhir_url()), data=json.dumps(res), headers=self.headers, verify=self.validate_certs)
         if response.status_code == 200:
             params = ParameterFHIR(resource=json.loads(response.content.decode()))
             if params.fhir_resource is not None and params.fhir_resource.parameter is not None:
@@ -1420,7 +1420,7 @@ class PatientFHIR(BaseFHIR):
         elif self.birth_date is not None:
             params['birthdate'] = self.birth_date
         response = requests.get(url=self.patient_endpoint.format(
-            self.get_fhir_url()), params=params, headers=self.headers)
+            self.get_fhir_url()), params=params, headers=self.headers, verify=self.validate_certs)
 
         return response
 
@@ -1938,8 +1938,9 @@ class OrganizationFHIR(BaseFHIR):
     rrss_system = 'https://pro.consultation.rrss.rtss.qc.ca'
     rrss_mot_cle_extension_url = 'http://www.santepublique.rtss.qc.ca/sipmi/rrss/1.0.0/extensions/#motscles'
 
-    def __init__(self, base_url=None, base_uri=None, resource=None, token_header=None) -> None:
+    def __init__(self, base_url=None, base_uri=None, resource=None, token_header=None, validate_certs=True) -> None:
         super().__init__(base_url=base_url, base_uri=base_uri, token_header=token_header)
+        self.validate_certs = validate_certs
         if resource is not None:
             self.fhir_resource = Organization(jsondict=resource)
         else:
@@ -1988,7 +1989,7 @@ class OrganizationFHIR(BaseFHIR):
             params['name'] = name
         if identifier is not None:
             params['identifier'] = identifier
-        response = requests.get(url=self.organization_endpoint.format(base_url=self.get_fhir_url()), params=params, headers=self.headers)
+        response = requests.get(url=self.organization_endpoint.format(base_url=self.get_fhir_url()), params=params, headers=self.headers, verify=self.validate_certs)
         content = json.loads(response.content.decode())
        
         return self.get_visitor_from_json(jsondict=content)
@@ -1999,8 +2000,9 @@ class LocationFHIR(BaseFHIR):
     rrss_system = 'https://pro.consultation.rrss.rtss.qc.ca'
     rrss_mot_cle_extension_url = 'http://www.santepublique.rtss.qc.ca/sipmi/rrss/1.0.0/extensions/#motscles'
 
-    def __init__(self, base_url=None, base_uri=None, resource=None, token_header=None) -> None:
+    def __init__(self, base_url=None, base_uri=None, resource=None, token_header=None, validate_certs=True) -> None:
         super().__init__(base_url=base_url, base_uri=base_uri, token_header=token_header)
+        self.validate_certs = validate_certs
         if resource is not None:
             self.fhir_resource = Location(jsondict=resource)
         else:
@@ -2051,7 +2053,7 @@ class LocationFHIR(BaseFHIR):
             params['identifier'] = identifier
         if address_city is not None:
             params['address-city'] = address_city
-        response = requests.get(url=self.location_endpoint.format(base_url=self.get_fhir_url()), params=params, headers=self.headers)
+        response = requests.get(url=self.location_endpoint.format(base_url=self.get_fhir_url()), params=params, headers=self.headers, verify=self.validate_certs)
         content = json.loads(response.content.decode())
     
         return self.get_visitor_from_json(jsondict=content)
